# coding: utf-8

# flake8: noqa

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.1"

# import apis into sdk package
from trinsic_api.api.attachments_api import AttachmentsApi
from trinsic_api.api.network_api import NetworkApi
from trinsic_api.api.sessions_api import SessionsApi
from trinsic_api.api.well_known_api import WellKnownApi

# import ApiClient
from trinsic_api.api_response import ApiResponse
from trinsic_api.api_client import ApiClient
from trinsic_api.configuration import Configuration
from trinsic_api.exceptions import OpenApiException
from trinsic_api.exceptions import ApiTypeError
from trinsic_api.exceptions import ApiValueError
from trinsic_api.exceptions import ApiKeyError
from trinsic_api.exceptions import ApiAttributeError
from trinsic_api.exceptions import ApiException

# import models into sdk package
from trinsic_api.models.aadhaar_input import AadhaarInput
from trinsic_api.models.address import Address
from trinsic_api.models.attachment_access_keys import AttachmentAccessKeys
from trinsic_api.models.bangladesh_national_id_input import BangladeshNationalIdInput
from trinsic_api.models.brazil_cpf_check_input import BrazilCpfCheckInput
from trinsic_api.models.brazil_digital_cnh_input import BrazilDigitalCnhInput
from trinsic_api.models.cancel_session_response import CancelSessionResponse
from trinsic_api.models.create_advanced_provider_session_request import CreateAdvancedProviderSessionRequest
from trinsic_api.models.create_advanced_provider_session_response import CreateAdvancedProviderSessionResponse
from trinsic_api.models.create_hosted_provider_session_request import CreateHostedProviderSessionRequest
from trinsic_api.models.create_hosted_provider_session_response import CreateHostedProviderSessionResponse
from trinsic_api.models.create_widget_session_request import CreateWidgetSessionRequest
from trinsic_api.models.create_widget_session_response import CreateWidgetSessionResponse
from trinsic_api.models.document_data import DocumentData
from trinsic_api.models.document_scan_attachments import DocumentScanAttachments
from trinsic_api.models.document_type import DocumentType
from trinsic_api.models.get_attachment_request import GetAttachmentRequest
from trinsic_api.models.get_attachment_response import GetAttachmentResponse
from trinsic_api.models.get_session_response import GetSessionResponse
from trinsic_api.models.get_session_result_request import GetSessionResultRequest
from trinsic_api.models.get_session_result_response import GetSessionResultResponse
from trinsic_api.models.http_validation_problem_details import HttpValidationProblemDetails
from trinsic_api.models.identity_data import IdentityData
from trinsic_api.models.idin_input import IdinInput
from trinsic_api.models.indonesia_nik_input import IndonesiaNikInput
from trinsic_api.models.integration_capability import IntegrationCapability
from trinsic_api.models.integration_launch_method import IntegrationLaunchMethod
from trinsic_api.models.integration_step import IntegrationStep
from trinsic_api.models.kenya_nid_input import KenyaNidInput
from trinsic_api.models.language import Language
from trinsic_api.models.list_provider_contracts_response import ListProviderContractsResponse
from trinsic_api.models.list_providers_response import ListProvidersResponse
from trinsic_api.models.list_sessions_response import ListSessionsResponse
from trinsic_api.models.mexico_curp_input import MexicoCurpInput
from trinsic_api.models.mobile_id_input import MobileIdInput
from trinsic_api.models.nigeria_nin_input import NigeriaNinInput
from trinsic_api.models.order_direction import OrderDirection
from trinsic_api.models.person_data import PersonData
from trinsic_api.models.philippine_match_input import PhilippineMatchInput
from trinsic_api.models.philippine_qr_input import PhilippineQRInput
from trinsic_api.models.problem_details import ProblemDetails
from trinsic_api.models.provider_attachments import ProviderAttachments
from trinsic_api.models.provider_contract import ProviderContract
from trinsic_api.models.provider_health import ProviderHealth
from trinsic_api.models.provider_info import ProviderInfo
from trinsic_api.models.provider_information import ProviderInformation
from trinsic_api.models.provider_input import ProviderInput
from trinsic_api.models.recommend_request import RecommendRequest
from trinsic_api.models.recommend_response import RecommendResponse
from trinsic_api.models.recommendation_info import RecommendationInfo
from trinsic_api.models.refresh_step_content_request import RefreshStepContentRequest
from trinsic_api.models.refresh_step_content_response import RefreshStepContentResponse
from trinsic_api.models.result_collection import ResultCollection
from trinsic_api.models.result_collection_method import ResultCollectionMethod
from trinsic_api.models.session import Session
from trinsic_api.models.session_error_code import SessionErrorCode
from trinsic_api.models.session_ordering import SessionOrdering
from trinsic_api.models.sex import Sex
from trinsic_api.models.smart_id_input import SmartIdInput
from trinsic_api.models.south_africa_nid_input import SouthAfricaNidInput
from trinsic_api.models.spid_input import SpidInput
from trinsic_api.models.step_refresh_info import StepRefreshInfo
from trinsic_api.models.sub_provider_metadata import SubProviderMetadata
from trinsic_api.models.trinsic_test_database_lookup_input import TrinsicTestDatabaseLookupInput
from trinsic_api.models.trinsic_test_sub_providers_input import TrinsicTestSubProvidersInput



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from trinsic_api.models.integration_capability import IntegrationCapability
from trinsic_api.models.provider_input import ProviderInput
from typing import Optional, Set
from typing_extensions import Self

class CreateAdvancedProviderSessionRequest(BaseModel):
    """
    CreateAdvancedProviderSessionRequest
    """ # noqa: E501
    provider: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The ID of the provider to launch")
    provider_input: Optional[ProviderInput] = Field(default=None, description="Provider-specific input for those providers which require it.", alias="providerInput")
    redirect_url: Optional[StrictStr] = Field(default=None, description="The Redirect URL to which the user should be sent after the session is complete.              This field is required for providers which employ a redirect-based flow.", alias="redirectUrl")
    capabilities: Annotated[List[IntegrationCapability], Field(min_length=1)] = Field(description="The list of capabilities your integration supports. Capabilities are the core of Trinsic's whitelabel-with-optional-fallback offering.              Most capabilities align with either an `IntegrationLaunchMethod` or an `IntegrationCollectionMethod`. The exception being refresh content to support updating the content of the launch method.              For example, to support a basic redirect-based flow, you must include the `LaunchRedirect` and `CaptureRedirect` capabilities. To support a mobile deeplink / polling flow, you must include the `DeeplinkToMobile` and `PollForResults` capabilities.              If `FallbackToHostedUi` is `true`, Trinsic will automatically fall back to a Trinsic-hosted UI to cover any gaps in your integration's capabilities. If `FallbackToHostedUi` is `false`, gaps in your integration's capabilities will result in an error during Session creation.              Read more on how to integrate at <a href=\"https://docs.trinsic.id/docs/advanced-provider-sessions\">the guide on Advanced Provider Sessions</a>")
    fallback_to_hosted_ui: Optional[StrictBool] = Field(default=None, description="Whether the session should fall back to a Trinsic-hosted UI in certain instances.              Specifically, fallback will occur if any of the following are true: - You attempted to launch a provider which requires a capability you did not express support for     - In this case, Trinsic's hosted UI will perform the necessary capability - You attempted to launch a provider which requires input, and the input was either not provided or incomplete     - In this case, Trinsic's hosted UI will collect the necessary input from the user              If fallback occurs, the session's NextStep will always be LaunchBrowser, and the CollectionMethod will always be CaptureRedirect.              If this field is set to `true`, you must also: 1. Set the `RedirectUrl` field to a non-empty value 2. Include the `LaunchBrowser` and `CaptureRedirect` capabilities in the `Capabilities` field", alias="fallbackToHostedUI")
    __properties: ClassVar[List[str]] = ["provider", "providerInput", "redirectUrl", "capabilities", "fallbackToHostedUI"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateAdvancedProviderSessionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of provider_input
        if self.provider_input:
            _dict['providerInput'] = self.provider_input.to_dict()
        # set to None if provider_input (nullable) is None
        # and model_fields_set contains the field
        if self.provider_input is None and "provider_input" in self.model_fields_set:
            _dict['providerInput'] = None

        # set to None if redirect_url (nullable) is None
        # and model_fields_set contains the field
        if self.redirect_url is None and "redirect_url" in self.model_fields_set:
            _dict['redirectUrl'] = None

        # set to None if fallback_to_hosted_ui (nullable) is None
        # and model_fields_set contains the field
        if self.fallback_to_hosted_ui is None and "fallback_to_hosted_ui" in self.model_fields_set:
            _dict['fallbackToHostedUI'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateAdvancedProviderSessionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "provider": obj.get("provider"),
            "providerInput": ProviderInput.from_dict(obj["providerInput"]) if obj.get("providerInput") is not None else None,
            "redirectUrl": obj.get("redirectUrl"),
            "capabilities": obj.get("capabilities"),
            "fallbackToHostedUI": obj.get("fallbackToHostedUI")
        })
        return _obj





# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from trinsic_api.models.aadhaar_input import AadhaarInput
from trinsic_api.models.bangladesh_national_id_input import BangladeshNationalIdInput
from trinsic_api.models.brazil_cpf_check_input import BrazilCpfCheckInput
from trinsic_api.models.brazil_digital_cnh_input import BrazilDigitalCnhInput
from trinsic_api.models.idin_input import IdinInput
from trinsic_api.models.indonesia_nik_input import IndonesiaNikInput
from trinsic_api.models.kenya_nid_input import KenyaNidInput
from trinsic_api.models.mexico_curp_input import MexicoCurpInput
from trinsic_api.models.mobile_id_input import MobileIdInput
from trinsic_api.models.nigeria_nin_input import NigeriaNinInput
from trinsic_api.models.philippine_match_input import PhilippineMatchInput
from trinsic_api.models.philippine_qr_input import PhilippineQRInput
from trinsic_api.models.smart_id_input import SmartIdInput
from trinsic_api.models.south_africa_nid_input import SouthAfricaNidInput
from trinsic_api.models.spid_input import SpidInput
from trinsic_api.models.trinsic_test_database_lookup_input import TrinsicTestDatabaseLookupInput
from trinsic_api.models.trinsic_test_sub_providers_input import TrinsicTestSubProvidersInput
from typing import Optional, Set
from typing_extensions import Self

class ProviderInput(BaseModel):
    """
    ProviderInput
    """ # noqa: E501
    indonesia_nik: Optional[IndonesiaNikInput] = Field(default=None, description="Input for the `f-indonesia-nik` provider", alias="indonesiaNik")
    mexico_curp: Optional[MexicoCurpInput] = Field(default=None, description="Input for the `f-mexico-curp` provider", alias="mexicoCurp")
    south_africa_nid: Optional[SouthAfricaNidInput] = Field(default=None, description="Input for the `f-south-africa-nid` provider", alias="southAfricaNid")
    kenya_nid: Optional[KenyaNidInput] = Field(default=None, description="Input for the `f-kenya-nid` provider", alias="kenyaNid")
    nigeria_nin: Optional[NigeriaNinInput] = Field(default=None, description="Input for the `f-nigeria-nin` provider", alias="nigeriaNin")
    aadhaar: Optional[AadhaarInput] = Field(default=None, description="Input for the `f-india-aadhaar-match` provider")
    bangladesh_national_id: Optional[BangladeshNationalIdInput] = Field(default=None, description="Input for the `bangladesh-nid` provider", alias="bangladeshNationalId")
    brazil_cpf_check: Optional[BrazilCpfCheckInput] = Field(default=None, description="Input for the `g-brazil-cpf` provider", alias="brazilCpfCheck")
    brazil_digital_cnh: Optional[BrazilDigitalCnhInput] = Field(default=None, description="Input for the `g-brazil-digital-cnh` provider", alias="brazilDigitalCnh")
    philippine_match: Optional[PhilippineMatchInput] = Field(default=None, description="Input for the `b-philsys-biometric` provider", alias="philippineMatch")
    philippine_qr: Optional[PhilippineQRInput] = Field(default=None, description="Input for the `b-philippine-qr-digital-national-id` and `b-philippine-qr-ephill-id` providers", alias="philippineQR")
    smart_id: Optional[SmartIdInput] = Field(default=None, description="Input for the `smart-id` provider", alias="smartId")
    mobile_id: Optional[MobileIdInput] = Field(default=None, description="Input for the `mobile-id` provider", alias="mobileId")
    idin: Optional[IdinInput] = Field(default=None, description="Input for the `idin` provider")
    spid: Optional[SpidInput] = Field(default=None, description="Input for the `spid` provider")
    trinsic_test_database_lookup: Optional[TrinsicTestDatabaseLookupInput] = Field(default=None, description="*TEST MODE ONLY.*              Input for the `trinsic-test-database-lookup` provider", alias="trinsicTestDatabaseLookup")
    trinsic_test_sub_providers: Optional[TrinsicTestSubProvidersInput] = Field(default=None, description="*TEST MODE ONLY.*              Input for the `trinsic-test-sub-providers` provider", alias="trinsicTestSubProviders")
    __properties: ClassVar[List[str]] = ["indonesiaNik", "mexicoCurp", "southAfricaNid", "kenyaNid", "nigeriaNin", "aadhaar", "bangladeshNationalId", "brazilCpfCheck", "brazilDigitalCnh", "philippineMatch", "philippineQR", "smartId", "mobileId", "idin", "spid", "trinsicTestDatabaseLookup", "trinsicTestSubProviders"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProviderInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of indonesia_nik
        if self.indonesia_nik:
            _dict['indonesiaNik'] = self.indonesia_nik.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mexico_curp
        if self.mexico_curp:
            _dict['mexicoCurp'] = self.mexico_curp.to_dict()
        # override the default output from pydantic by calling `to_dict()` of south_africa_nid
        if self.south_africa_nid:
            _dict['southAfricaNid'] = self.south_africa_nid.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kenya_nid
        if self.kenya_nid:
            _dict['kenyaNid'] = self.kenya_nid.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nigeria_nin
        if self.nigeria_nin:
            _dict['nigeriaNin'] = self.nigeria_nin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of aadhaar
        if self.aadhaar:
            _dict['aadhaar'] = self.aadhaar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bangladesh_national_id
        if self.bangladesh_national_id:
            _dict['bangladeshNationalId'] = self.bangladesh_national_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of brazil_cpf_check
        if self.brazil_cpf_check:
            _dict['brazilCpfCheck'] = self.brazil_cpf_check.to_dict()
        # override the default output from pydantic by calling `to_dict()` of brazil_digital_cnh
        if self.brazil_digital_cnh:
            _dict['brazilDigitalCnh'] = self.brazil_digital_cnh.to_dict()
        # override the default output from pydantic by calling `to_dict()` of philippine_match
        if self.philippine_match:
            _dict['philippineMatch'] = self.philippine_match.to_dict()
        # override the default output from pydantic by calling `to_dict()` of philippine_qr
        if self.philippine_qr:
            _dict['philippineQR'] = self.philippine_qr.to_dict()
        # override the default output from pydantic by calling `to_dict()` of smart_id
        if self.smart_id:
            _dict['smartId'] = self.smart_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mobile_id
        if self.mobile_id:
            _dict['mobileId'] = self.mobile_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of idin
        if self.idin:
            _dict['idin'] = self.idin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spid
        if self.spid:
            _dict['spid'] = self.spid.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trinsic_test_database_lookup
        if self.trinsic_test_database_lookup:
            _dict['trinsicTestDatabaseLookup'] = self.trinsic_test_database_lookup.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trinsic_test_sub_providers
        if self.trinsic_test_sub_providers:
            _dict['trinsicTestSubProviders'] = self.trinsic_test_sub_providers.to_dict()
        # set to None if indonesia_nik (nullable) is None
        # and model_fields_set contains the field
        if self.indonesia_nik is None and "indonesia_nik" in self.model_fields_set:
            _dict['indonesiaNik'] = None

        # set to None if mexico_curp (nullable) is None
        # and model_fields_set contains the field
        if self.mexico_curp is None and "mexico_curp" in self.model_fields_set:
            _dict['mexicoCurp'] = None

        # set to None if south_africa_nid (nullable) is None
        # and model_fields_set contains the field
        if self.south_africa_nid is None and "south_africa_nid" in self.model_fields_set:
            _dict['southAfricaNid'] = None

        # set to None if kenya_nid (nullable) is None
        # and model_fields_set contains the field
        if self.kenya_nid is None and "kenya_nid" in self.model_fields_set:
            _dict['kenyaNid'] = None

        # set to None if nigeria_nin (nullable) is None
        # and model_fields_set contains the field
        if self.nigeria_nin is None and "nigeria_nin" in self.model_fields_set:
            _dict['nigeriaNin'] = None

        # set to None if aadhaar (nullable) is None
        # and model_fields_set contains the field
        if self.aadhaar is None and "aadhaar" in self.model_fields_set:
            _dict['aadhaar'] = None

        # set to None if bangladesh_national_id (nullable) is None
        # and model_fields_set contains the field
        if self.bangladesh_national_id is None and "bangladesh_national_id" in self.model_fields_set:
            _dict['bangladeshNationalId'] = None

        # set to None if brazil_cpf_check (nullable) is None
        # and model_fields_set contains the field
        if self.brazil_cpf_check is None and "brazil_cpf_check" in self.model_fields_set:
            _dict['brazilCpfCheck'] = None

        # set to None if brazil_digital_cnh (nullable) is None
        # and model_fields_set contains the field
        if self.brazil_digital_cnh is None and "brazil_digital_cnh" in self.model_fields_set:
            _dict['brazilDigitalCnh'] = None

        # set to None if philippine_match (nullable) is None
        # and model_fields_set contains the field
        if self.philippine_match is None and "philippine_match" in self.model_fields_set:
            _dict['philippineMatch'] = None

        # set to None if philippine_qr (nullable) is None
        # and model_fields_set contains the field
        if self.philippine_qr is None and "philippine_qr" in self.model_fields_set:
            _dict['philippineQR'] = None

        # set to None if smart_id (nullable) is None
        # and model_fields_set contains the field
        if self.smart_id is None and "smart_id" in self.model_fields_set:
            _dict['smartId'] = None

        # set to None if mobile_id (nullable) is None
        # and model_fields_set contains the field
        if self.mobile_id is None and "mobile_id" in self.model_fields_set:
            _dict['mobileId'] = None

        # set to None if idin (nullable) is None
        # and model_fields_set contains the field
        if self.idin is None and "idin" in self.model_fields_set:
            _dict['idin'] = None

        # set to None if spid (nullable) is None
        # and model_fields_set contains the field
        if self.spid is None and "spid" in self.model_fields_set:
            _dict['spid'] = None

        # set to None if trinsic_test_database_lookup (nullable) is None
        # and model_fields_set contains the field
        if self.trinsic_test_database_lookup is None and "trinsic_test_database_lookup" in self.model_fields_set:
            _dict['trinsicTestDatabaseLookup'] = None

        # set to None if trinsic_test_sub_providers (nullable) is None
        # and model_fields_set contains the field
        if self.trinsic_test_sub_providers is None and "trinsic_test_sub_providers" in self.model_fields_set:
            _dict['trinsicTestSubProviders'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProviderInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "indonesiaNik": IndonesiaNikInput.from_dict(obj["indonesiaNik"]) if obj.get("indonesiaNik") is not None else None,
            "mexicoCurp": MexicoCurpInput.from_dict(obj["mexicoCurp"]) if obj.get("mexicoCurp") is not None else None,
            "southAfricaNid": SouthAfricaNidInput.from_dict(obj["southAfricaNid"]) if obj.get("southAfricaNid") is not None else None,
            "kenyaNid": KenyaNidInput.from_dict(obj["kenyaNid"]) if obj.get("kenyaNid") is not None else None,
            "nigeriaNin": NigeriaNinInput.from_dict(obj["nigeriaNin"]) if obj.get("nigeriaNin") is not None else None,
            "aadhaar": AadhaarInput.from_dict(obj["aadhaar"]) if obj.get("aadhaar") is not None else None,
            "bangladeshNationalId": BangladeshNationalIdInput.from_dict(obj["bangladeshNationalId"]) if obj.get("bangladeshNationalId") is not None else None,
            "brazilCpfCheck": BrazilCpfCheckInput.from_dict(obj["brazilCpfCheck"]) if obj.get("brazilCpfCheck") is not None else None,
            "brazilDigitalCnh": BrazilDigitalCnhInput.from_dict(obj["brazilDigitalCnh"]) if obj.get("brazilDigitalCnh") is not None else None,
            "philippineMatch": PhilippineMatchInput.from_dict(obj["philippineMatch"]) if obj.get("philippineMatch") is not None else None,
            "philippineQR": PhilippineQRInput.from_dict(obj["philippineQR"]) if obj.get("philippineQR") is not None else None,
            "smartId": SmartIdInput.from_dict(obj["smartId"]) if obj.get("smartId") is not None else None,
            "mobileId": MobileIdInput.from_dict(obj["mobileId"]) if obj.get("mobileId") is not None else None,
            "idin": IdinInput.from_dict(obj["idin"]) if obj.get("idin") is not None else None,
            "spid": SpidInput.from_dict(obj["spid"]) if obj.get("spid") is not None else None,
            "trinsicTestDatabaseLookup": TrinsicTestDatabaseLookupInput.from_dict(obj["trinsicTestDatabaseLookup"]) if obj.get("trinsicTestDatabaseLookup") is not None else None,
            "trinsicTestSubProviders": TrinsicTestSubProvidersInput.from_dict(obj["trinsicTestSubProviders"]) if obj.get("trinsicTestSubProviders") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.api.well_known_api import WellKnownApi


class TestWellKnownApi(unittest.TestCase):
    """WellKnownApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WellKnownApi()

    def tearDown(self) -> None:
        pass

    def test_interac_jwk(self) -> None:
        """Test case for interac_jwk

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from trinsic_api.models.integration_launch_method import IntegrationLaunchMethod
from trinsic_api.models.provider_health import ProviderHealth
from trinsic_api.models.result_collection_method import ResultCollectionMethod
from trinsic_api.models.sub_provider_metadata import SubProviderMetadata
from typing import Optional, Set
from typing_extensions import Self

class ProviderContract(BaseModel):
    """
    ProviderContract
    """ # noqa: E501
    id: StrictStr = Field(description="The ID of the Provider for this contract.")
    name: StrictStr = Field(description="The Provider's Name as it appears in Trinsic's Dashboard and Widget")
    description: StrictStr = Field(description="The Provider's description as it appears in Trinsic's Widget.              This is flavor text, not a full, human-readable description of the provider.")
    logo_url: StrictStr = Field(description="A URL pointing to the Provider's logo on Trinsic's CDN.              May be a PNG, JPG, or SVG image.", alias="logoUrl")
    available: StrictBool = Field(description="Whether the Provider is available for use in your App.              If `false`, you will need to contact Trinsic to enable this Provider for your App.")
    geography: List[StrictStr] = Field(description="The geographies within the Regions the Provider is available.")
    regions: List[StrictStr] = Field(description="The regions within which the Provider is available.")
    launch_method: IntegrationLaunchMethod = Field(description="Relevant only to Advanced Provider Sessions.              The `LaunchMethod` which must be supported to launch the Provider Session in Advanced Provider Sessions.", alias="launchMethod")
    collection_method: ResultCollectionMethod = Field(description="Relevant only to Advanced Provider Sessions.              The `CollectionMethod` which must be supported to launch the Provider Session in Advanced Provider Sessions.", alias="collectionMethod")
    results_may_be_delayed_after_redirect: StrictBool = Field(description="If `true`, then the results for this Provider may not be available immediately after the user is redirected back to your application. In this case, the `GetSessionResults` API must be called until results are available.              This is an uncommon scenario, and typically only applies to Providers which use a biometric check or traditional document scan.", alias="resultsMayBeDelayedAfterRedirect")
    has_refreshable_content: StrictBool = Field(description="Relevant only to Advanced Provider Sessions.              Whether the Provider requires the `RefreshStepContent` capability.              For example, Samsung Wallet's deep links expire every 30 seconds, and must be refreshed periodically for a resilient user flow.", alias="hasRefreshableContent")
    requires_input: StrictBool = Field(description="Relevant to Hosted Provider Sessions and Advanced Provider Sessions.              If `true`, this Provider requires provider-specific input on Session creation. If this input is not provided, Trinsic's Hosted UI will be invoked to collect the input from the user.", alias="requiresInput")
    has_trinsic_interface: StrictBool = Field(description="Whether there exists a Trinsic-hosted UI for this Provider.              This is `true` for any Provider which is not a simple, OIDC-like redirect flow.", alias="hasTrinsicInterface")
    supports_advanced_provider_sessions: StrictBool = Field(description="Whether this Provider can be fully whitelabeled/OEMed through the Advanced Provider Sessions API.              If `false`, the Provider may still be launched through Advanced Provider Sessions; however, it will necessarily require a Trinsic-hosted UI to function.", alias="supportsAdvancedProviderSessions")
    sub_providers: Optional[List[SubProviderMetadata]] = Field(default=None, description="Metadata about the sub-providers which are available for this Provider.              For example, Italy's SPID is a Provider which aggregates access to multiple sub-providers.", alias="subProviders")
    status: ProviderHealth = Field(description="The current status of the provider and if it is available to launch. If the status is disabled, there is an issue that prevents a provider being able to launch a session.")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "logoUrl", "available", "geography", "regions", "launchMethod", "collectionMethod", "resultsMayBeDelayedAfterRedirect", "hasRefreshableContent", "requiresInput", "hasTrinsicInterface", "supportsAdvancedProviderSessions", "subProviders", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProviderContract from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in sub_providers (list)
        _items = []
        if self.sub_providers:
            for _item_sub_providers in self.sub_providers:
                if _item_sub_providers:
                    _items.append(_item_sub_providers.to_dict())
            _dict['subProviders'] = _items
        # set to None if sub_providers (nullable) is None
        # and model_fields_set contains the field
        if self.sub_providers is None and "sub_providers" in self.model_fields_set:
            _dict['subProviders'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProviderContract from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "logoUrl": obj.get("logoUrl"),
            "available": obj.get("available"),
            "geography": obj.get("geography"),
            "regions": obj.get("regions"),
            "launchMethod": obj.get("launchMethod"),
            "collectionMethod": obj.get("collectionMethod"),
            "resultsMayBeDelayedAfterRedirect": obj.get("resultsMayBeDelayedAfterRedirect"),
            "hasRefreshableContent": obj.get("hasRefreshableContent"),
            "requiresInput": obj.get("requiresInput"),
            "hasTrinsicInterface": obj.get("hasTrinsicInterface"),
            "supportsAdvancedProviderSessions": obj.get("supportsAdvancedProviderSessions"),
            "subProviders": [SubProviderMetadata.from_dict(_item) for _item in obj["subProviders"]] if obj.get("subProviders") is not None else None,
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.provider_input import ProviderInput

class TestProviderInput(unittest.TestCase):
    """ProviderInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProviderInput:
        """Test ProviderInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProviderInput`
        """
        model = ProviderInput()
        if include_optional:
            return ProviderInput(
                indonesia_nik = trinsic_api.models.indonesia_nik_input.IndonesiaNikInput(
                    full_name = '0', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    nik_id_number = '48072888001528021798090123456789101112131415', ),
                mexico_curp = trinsic_api.models.mexico_curp_input.MexicoCurpInput(
                    curp = '01234567891011121314151617', ),
                south_africa_nid = trinsic_api.models.south_africa_nid_input.SouthAfricaNidInput(
                    full_name = '0', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    gender = '0', 
                    national_id_number = '48072888001528021798090123456789101112', ),
                kenya_nid = trinsic_api.models.kenya_nid_input.KenyaNidInput(
                    first_name = '0', 
                    middle_name = '', 
                    last_name = '0', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    gender = '0', 
                    national_id_number = '480728880015280217980901234567', ),
                nigeria_nin = trinsic_api.models.nigeria_nin_input.NigeriaNinInput(
                    first_name = '0', 
                    middle_name = '', 
                    last_name = '0', 
                    phone_number = '', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    gender = '', 
                    national_id_number = '4807288800152802179809012345678910', ),
                aadhaar = trinsic_api.models.aadhaar_input.AadhaarInput(
                    full_name = '', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ),
                bangladesh_national_id = trinsic_api.models.bangladesh_national_id_input.BangladeshNationalIdInput(
                    national_id_number = '', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    name = '', 
                    photo_base64 = '', ),
                brazil_cpf_check = trinsic_api.models.brazil_cpf_check_input.BrazilCpfCheckInput(
                    cpf_number = '4807288800152802179809012345678910', ),
                brazil_digital_cnh = trinsic_api.models.brazil_digital_cnh_input.BrazilDigitalCnhInput(
                    cpf_number = '4807288800152802179809012345678910', 
                    digital_cnh_file = 'YQ==', 
                    digital_cnh_file_content_type = '', 
                    facial_biometry_photo = 'YQ==', ),
                philippine_match = trinsic_api.models.philippine_match_input.PhilippineMatchInput(
                    given_name = '', 
                    middle_name = '', 
                    family_name = '', 
                    suffix = '', 
                    date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ),
                philippine_qr = trinsic_api.models.philippine_qr_input.PhilippineQRInput(
                    qr_code_text = '', 
                    qr_code_image = 'YQ==', ),
                smart_id = trinsic_api.models.smart_id_input.SmartIdInput(
                    smart_id_document_number = '', ),
                mobile_id = trinsic_api.models.mobile_id_input.MobileIdInput(
                    mobile_id_phone_number = '', 
                    mobile_id_national_identity_number = '', 
                    mobile_id_language = null, ),
                idin = trinsic_api.models.idin_input.IdinInput(
                    sub_provider_id = '', ),
                spid = trinsic_api.models.spid_input.SpidInput(
                    sub_provider_id = '', ),
                trinsic_test_database_lookup = trinsic_api.models.trinsic_test_database_lookup_input.TrinsicTestDatabaseLookupInput(
                    given_name = '', 
                    family_name = '', 
                    identity_code = '', 
                    selfie_base64 = '', ),
                trinsic_test_sub_providers = trinsic_api.models.trinsic_test_sub_providers_input.TrinsicTestSubProvidersInput(
                    sub_provider_id = '', )
            )
        else:
            return ProviderInput(
        )
        """

    def testProviderInput(self):
        """Test ProviderInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.refresh_step_content_response import RefreshStepContentResponse

class TestRefreshStepContentResponse(unittest.TestCase):
    """RefreshStepContentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RefreshStepContentResponse:
        """Test RefreshStepContentResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RefreshStepContentResponse`
        """
        model = RefreshStepContentResponse()
        if include_optional:
            return RefreshStepContentResponse(
                next_step = trinsic_api.models.integration_step.IntegrationStep(
                    method = LaunchBrowser, 
                    content = 'https://api.trinsic.id/api/session/launch?clientToken=...', 
                    refresh = null, )
            )
        else:
            return RefreshStepContentResponse(
                next_step = trinsic_api.models.integration_step.IntegrationStep(
                    method = LaunchBrowser, 
                    content = 'https://api.trinsic.id/api/session/launch?clientToken=...', 
                    refresh = null, ),
        )
        """

    def testRefreshStepContentResponse(self):
        """Test RefreshStepContentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.provider_contract import ProviderContract

class TestProviderContract(unittest.TestCase):
    """ProviderContract unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProviderContract:
        """Test ProviderContract
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProviderContract`
        """
        model = ProviderContract()
        if include_optional:
            return ProviderContract(
                id = 'ca-mdl',
                name = 'CA DMV',
                description = 'dmv.ca.gov',
                logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png',
                available = True,
                geography = ["CA"],
                regions = ["United States"],
                launch_method = 'LaunchBrowser',
                collection_method = 'PollResult',
                results_may_be_delayed_after_redirect = False,
                has_refreshable_content = False,
                requires_input = False,
                has_trinsic_interface = True,
                supports_advanced_provider_sessions = True,
                sub_providers = [
                    trinsic_api.models.sub_provider_metadata.SubProviderMetadata(
                        id = '', 
                        name = '', 
                        description = '', 
                        logo_url = '', )
                    ],
                status = 'Online'
            )
        else:
            return ProviderContract(
                id = 'ca-mdl',
                name = 'CA DMV',
                description = 'dmv.ca.gov',
                logo_url = 'https://content.trinsic.id/connect/integrations/ca-dmv.png',
                available = True,
                geography = ["CA"],
                regions = ["United States"],
                launch_method = 'LaunchBrowser',
                collection_method = 'PollResult',
                results_may_be_delayed_after_redirect = False,
                has_refreshable_content = False,
                requires_input = False,
                has_trinsic_interface = True,
                supports_advanced_provider_sessions = True,
                status = 'Online',
        )
        """

    def testProviderContract(self):
        """Test ProviderContract"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.nigeria_nin_input import NigeriaNinInput

class TestNigeriaNinInput(unittest.TestCase):
    """NigeriaNinInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NigeriaNinInput:
        """Test NigeriaNinInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NigeriaNinInput`
        """
        model = NigeriaNinInput()
        if include_optional:
            return NigeriaNinInput(
                first_name = '0',
                middle_name = '',
                last_name = '0',
                phone_number = '',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                gender = '',
                national_id_number = '4807288800152802179809012345678910'
            )
        else:
            return NigeriaNinInput(
                first_name = '0',
                last_name = '0',
                date_of_birth = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                national_id_number = '4807288800152802179809012345678910',
        )
        """

    def testNigeriaNinInput(self):
        """Test NigeriaNinInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "Trinsic-Api"
VERSION = "2.0.1"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="Trinsic API",
    author="trinsic-id",
    author_email="support@trinsic.id",
    url="https://trinsic.id",
    keywords=["Trinsic", "SDK", "Identity verification"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license_files="LICENSE",
    long_description_content_type='text/markdown',
    long_description=long_description,
    package_data={"trinsic_api": ["py.typed"]},
)



# coding: utf-8

"""
    Trinsic API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from trinsic_api.models.result_collection_method import ResultCollectionMethod

class TestResultCollectionMethod(unittest.TestCase):
    """ResultCollectionMethod unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResultCollectionMethod(self):
        """Test ResultCollectionMethod"""
        # inst = ResultCollectionMethod()

if __name__ == '__main__':
    unittest.main()
